==> nextcloud-14.0.13.zip: nextcloud/apps/password_policy/l10n/es.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "La contraseña debe tener al menos %s caracteres",
    "Password needs to contain at least one lower and one upper case character." : "La contraseña debe contener al menos una minúscula y una mayúscula",
    "Password needs to contain at least one numeric character." : "La contraseña debe contener al menos un número",
    "Password needs to contain at least one special character." : "La contraseña debe contener al menos un carácter especial.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contraseña está entre el millón más común. Por favor, elige una diferente.",
    "Password is present in compromised password list. Please choose a different password." : "La contraseña se encuentra en una lista de contraseñas filtradas. Por favor, escoge una contraseña diferente.",
    "Password policy" : "Política de contraseñas",
    "Allows admins to configure a password policy" : "Permite a los administradores configurar una política de contraseñas",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permite a los administradores definir ciertas precondiciones para las contraseñas, p. ej., obligar a una longitud mínima",
    "Minimal length" : "Longitud mínima",
    "Forbid common passwords" : "Prohibir contraseñas comunes",
    "Enforce upper and lower case characters" : "Imponer caracteres en mayúsculas y minúsculas",
    "Enforce numeric characters" : "Imponer caracteres numéricos",
    "Enforce special characters" : "Imponer caracteres especiales",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar contraseña contra la lista de contraseñas filtradas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un hash de las contraseñas y envía los 5 primeros caracteres de este hash a la API de haveibeenpwned.com para recuperar una lista de todos los hashes que comienzan de esa forma. Después se comprueba en la instancia de Nextcloud si el hash de la contraseña está en el conjunto de resultados."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.6.zip: nextcloud/apps/password_policy/l10n/es.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "La contraseña ha caducado. Por favor, usa el método de contraseña olvidada para resetearla.",
    "Password must not have been used recently before." : "La contraseña no debe haber sido utilizada recientemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contraseña está entre el millón más común. Por favor, elige una diferente.",
    "Password is present in compromised password list. Please choose a different password." : "La contraseña se encuentra en una lista de contraseñas filtradas. Por favor, escoge una contraseña diferente.",
    "Password needs to be at least %s characters long" : "La contraseña debe tener al menos %s caracteres",
    "Password needs to contain at least one numeric character." : "La contraseña debe contener al menos un número.",
    "Password needs to contain at least one special character." : "La contraseña debe contener al menos un carácter especial.",
    "Password needs to contain at least one lower and one upper case character." : "La contraseña debe contener al menos una minúscula y una mayúscula.",
    "Password policy" : "Política de contraseñas",
    "Allows admins to configure a password policy" : "Permite a los administradores configurar una política de contraseñas",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permite a los administradores definir ciertas precondiciones para las contraseñas, p. ej., obligar a una longitud mínima",
    "Minimal length" : "Longitud mínima",
    "User password history" : "Histórico de contraseñas del usuario",
    "days until user password expires" : "días hasta que caduque la contraseña",
    "Forbid common passwords" : "Prohibir contraseñas comunes",
    "Enforce upper and lower case characters" : "Imponer caracteres en mayúsculas y minúsculas",
    "Enforce numeric characters" : "Imponer caracteres numéricos",
    "Enforce special characters" : "Imponer caracteres especiales",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Comprobar contraseña en la lista de contraseñas filtradas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta comprobación crea un hash de las contraseñas y envía los 5 primeros caracteres de este hash a la API de haveibeenpwned.com para recuperar una lista de todos los hashes que comienzan de esa forma. Después se comprueba en la instancia de Nextcloud si el hash de la contraseña está en el conjunto de resultados."
},
"nplurals=2; plural=(n != 1);");
